@@ -195,6 +195,18 @@ class Api(vi.BaseApi):
             token=token,
         )
 
+    def post_metadata_query(
+        self,
+        query: Any,
+        token: Optional[vi.AuthorizationToken] = None,
+    ) -> Any:
+        return self._authorized_request(
+            "POST",
+            "/metadata/query",
+            json=query,
+            token=token,
+        )
+
     def post_metadata_rawdata_query(
         self,
         query: Any,
